==> haskell-socks-0.6.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-768i3JAg6wiDiTyFmFiO1r
key:                  socks-0.6.1-768i3JAg6wiDiTyFmFiO1r
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  16a59fd5bfc307a040f7496aa14c6b38
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-8.8.2/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/socks-0.6.1
hs-libraries:         HSsocks-0.6.1-768i3JAg6wiDiTyFmFiO1r
depends:
    base-4.13.0.0 basement-0.0.11-2YL1SjOhLXc7VnIkv32HlL
    bytestring-0.10.10.0 cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs
    network-2.8.0.1-GLycSzRbjQc6b6XCSsLwiW

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.6.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-Y7T4ACn97HJZTfZ2PAVYo
key:                  socks-0.6.1-Y7T4ACn97HJZTfZ2PAVYo
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  fea8c89d5dac954462a96532c17fc50b
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-8.8.3/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/socks-0.6.1
hs-libraries:         HSsocks-0.6.1-Y7T4ACn97HJZTfZ2PAVYo
depends:
    base-4.13.0.0 basement-0.0.11-2YL1SjOhLXc7VnIkv32HlL
    bytestring-0.10.10.0 cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs
    network-2.8.0.1-Az808FcmCtCG39ffXHH2Iq

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
